.. _install:

Installing PyTensor
===================

The latest release of PyTensor can be installed from Pypi using `pip`:

.. code-block:: bash

    pip install pytensor


Or via conda-force:

.. code-block:: bash

    conda install -c conda-forge pytensor


The current development branch of PyTensor can be installed from GitHub using `pip`:


.. code-block:: bash

    pip install git+https://github.com/pymc-devs/pytensor


To use the Numba and JAX backend you will need to install these libraries in addition to PyTensor. Please refer to `Numba's installation instructions <https://numba.readthedocs.io/en/stable/user/installing.html>`__ and `JAX's installation instructions  <https://github.com/google/jax#installation>`__ respectively.
